/********************************************************************************
** Form generated from reading UI file 'pinyindictmanager.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PINYINDICTMANAGER_H
#define UI_PINYINDICTMANAGER_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QListView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <fcitxqti18nhelper.h>

QT_BEGIN_NAMESPACE

class Ui_PinyinDictManager
{
public:
    QHBoxLayout *horizontalLayout;
    QListView *listView_;
    QVBoxLayout *verticalLayout_;
    QPushButton *importButton_;
    QPushButton *removeButton_;
    QPushButton *removeAllButton_;
    QPushButton *clearDictButton_;
    QPushButton *openDirectoryButton_;
    QSpacerItem *verticalSpacer_;

    void setupUi(QWidget *PinyinDictManager)
    {
        if (PinyinDictManager->objectName().isEmpty())
            PinyinDictManager->setObjectName("PinyinDictManager");
        PinyinDictManager->resize(494, 356);
        horizontalLayout = new QHBoxLayout(PinyinDictManager);
        horizontalLayout->setObjectName("horizontalLayout");
        listView_ = new QListView(PinyinDictManager);
        listView_->setObjectName("listView_");

        horizontalLayout->addWidget(listView_);

        verticalLayout_ = new QVBoxLayout();
        verticalLayout_->setObjectName("verticalLayout_");
        importButton_ = new QPushButton(PinyinDictManager);
        importButton_->setObjectName("importButton_");
        QIcon icon;
        QString iconThemeName = QString::fromUtf8("list-add");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        importButton_->setIcon(icon);

        verticalLayout_->addWidget(importButton_);

        removeButton_ = new QPushButton(PinyinDictManager);
        removeButton_->setObjectName("removeButton_");
        QIcon icon1;
        iconThemeName = QString::fromUtf8("list-remove");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon1 = QIcon::fromTheme(iconThemeName);
        } else {
            icon1.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        removeButton_->setIcon(icon1);

        verticalLayout_->addWidget(removeButton_);

        removeAllButton_ = new QPushButton(PinyinDictManager);
        removeAllButton_->setObjectName("removeAllButton_");
        QIcon icon2;
        iconThemeName = QString::fromUtf8("edit-delete");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon2 = QIcon::fromTheme(iconThemeName);
        } else {
            icon2.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        removeAllButton_->setIcon(icon2);

        verticalLayout_->addWidget(removeAllButton_);

        clearDictButton_ = new QPushButton(PinyinDictManager);
        clearDictButton_->setObjectName("clearDictButton_");
        QIcon icon3;
        iconThemeName = QString::fromUtf8("document-revert");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon3 = QIcon::fromTheme(iconThemeName);
        } else {
            icon3.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        clearDictButton_->setIcon(icon3);

        verticalLayout_->addWidget(clearDictButton_);

        openDirectoryButton_ = new QPushButton(PinyinDictManager);
        openDirectoryButton_->setObjectName("openDirectoryButton_");
        QIcon icon4(QIcon::fromTheme(QString::fromUtf8("inode-directory")));
        openDirectoryButton_->setIcon(icon4);

        verticalLayout_->addWidget(openDirectoryButton_);

        verticalSpacer_ = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_->addItem(verticalSpacer_);


        horizontalLayout->addLayout(verticalLayout_);


        retranslateUi(PinyinDictManager);

        QMetaObject::connectSlotsByName(PinyinDictManager);
    } // setupUi

    void retranslateUi(QWidget *PinyinDictManager)
    {
        importButton_->setText(fcitx::tr2fcitx("&Import", nullptr));
        removeButton_->setText(fcitx::tr2fcitx("&Remove", nullptr));
        removeAllButton_->setText(fcitx::tr2fcitx("Remove &All", nullptr));
        clearDictButton_->setText(fcitx::tr2fcitx("&Clear Dictionary", nullptr));
        openDirectoryButton_->setText(fcitx::tr2fcitx("&Open User Data Directory", nullptr));
        (void)PinyinDictManager;
    } // retranslateUi

};

namespace Ui {
    class PinyinDictManager: public Ui_PinyinDictManager {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_PINYINDICTMANAGER_H
