/********************************************************************************
** Form generated from reading UI file 'customphraseeditor.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CUSTOMPHRASEEDITOR_H
#define UI_CUSTOMPHRASEEDITOR_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTableView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <fcitxqti18nhelper.h>

QT_BEGIN_NAMESPACE

class Ui_CustomPhraseEditor
{
public:
    QHBoxLayout *horizontalLayout;
    QTableView *tableView_;
    QVBoxLayout *verticalLayout_;
    QPushButton *addButton_;
    QPushButton *removeButton_;
    QPushButton *helpButton_;
    QPushButton *externalEditor_;
    QPushButton *clearButton_;
    QSpacerItem *verticalSpacer_;

    void setupUi(QWidget *CustomPhraseEditor)
    {
        if (CustomPhraseEditor->objectName().isEmpty())
            CustomPhraseEditor->setObjectName("CustomPhraseEditor");
        CustomPhraseEditor->resize(800, 600);
        CustomPhraseEditor->setMinimumSize(QSize(600, 400));
        horizontalLayout = new QHBoxLayout(CustomPhraseEditor);
        horizontalLayout->setObjectName("horizontalLayout");
        tableView_ = new QTableView(CustomPhraseEditor);
        tableView_->setObjectName("tableView_");
        tableView_->setSelectionMode(QAbstractItemView::SingleSelection);
        tableView_->setSelectionBehavior(QAbstractItemView::SelectRows);
        tableView_->horizontalHeader()->setStretchLastSection(true);
        tableView_->verticalHeader()->setVisible(false);

        horizontalLayout->addWidget(tableView_);

        verticalLayout_ = new QVBoxLayout();
        verticalLayout_->setObjectName("verticalLayout_");
        addButton_ = new QPushButton(CustomPhraseEditor);
        addButton_->setObjectName("addButton_");
        QIcon icon;
        QString iconThemeName = QString::fromUtf8("list-add");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        addButton_->setIcon(icon);

        verticalLayout_->addWidget(addButton_);

        removeButton_ = new QPushButton(CustomPhraseEditor);
        removeButton_->setObjectName("removeButton_");
        QIcon icon1;
        iconThemeName = QString::fromUtf8("list-remove");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon1 = QIcon::fromTheme(iconThemeName);
        } else {
            icon1.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        removeButton_->setIcon(icon1);

        verticalLayout_->addWidget(removeButton_);

        helpButton_ = new QPushButton(CustomPhraseEditor);
        helpButton_->setObjectName("helpButton_");
        QIcon icon2(QIcon::fromTheme(QString::fromUtf8("dialog-question")));
        helpButton_->setIcon(icon2);

        verticalLayout_->addWidget(helpButton_);

        externalEditor_ = new QPushButton(CustomPhraseEditor);
        externalEditor_->setObjectName("externalEditor_");
        QIcon icon3;
        iconThemeName = QString::fromUtf8("document-edit");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon3 = QIcon::fromTheme(iconThemeName);
        } else {
            icon3.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        externalEditor_->setIcon(icon3);

        verticalLayout_->addWidget(externalEditor_);

        clearButton_ = new QPushButton(CustomPhraseEditor);
        clearButton_->setObjectName("clearButton_");
        QIcon icon4;
        iconThemeName = QString::fromUtf8("edit-delete");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon4 = QIcon::fromTheme(iconThemeName);
        } else {
            icon4.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        clearButton_->setIcon(icon4);

        verticalLayout_->addWidget(clearButton_);

        verticalSpacer_ = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_->addItem(verticalSpacer_);


        horizontalLayout->addLayout(verticalLayout_);


        retranslateUi(CustomPhraseEditor);

        QMetaObject::connectSlotsByName(CustomPhraseEditor);
    } // setupUi

    void retranslateUi(QWidget *CustomPhraseEditor)
    {
        addButton_->setText(fcitx::tr2fcitx("&Add", nullptr));
        removeButton_->setText(fcitx::tr2fcitx("&Remove", nullptr));
        helpButton_->setText(fcitx::tr2fcitx("&Usage", nullptr));
        externalEditor_->setText(fcitx::tr2fcitx("&External Editor", nullptr));
        clearButton_->setText(fcitx::tr2fcitx("&Clear", nullptr));
        (void)CustomPhraseEditor;
    } // retranslateUi

};

namespace Ui {
    class CustomPhraseEditor: public Ui_CustomPhraseEditor {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CUSTOMPHRASEEDITOR_H
