/********************************************************************************
** Form generated from reading UI file 'browserdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BROWSERDIALOG_H
#define UI_BROWSERDIALOG_H

#include <QtCore/QVariant>
#include <QtWebEngineWidgets/QWebEngineView>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QVBoxLayout>
#include <fcitxqti18nhelper.h>

QT_BEGIN_NAMESPACE

class Ui_BrowserDialog
{
public:
    QVBoxLayout *verticalLayout;
    QWebEngineView *webView_;
    QProgressBar *progressBar_;

    void setupUi(QDialog *BrowserDialog)
    {
        if (BrowserDialog->objectName().isEmpty())
            BrowserDialog->setObjectName("BrowserDialog");
        BrowserDialog->resize(1200, 600);
        verticalLayout = new QVBoxLayout(BrowserDialog);
        verticalLayout->setObjectName("verticalLayout");
        webView_ = new QWebEngineView(BrowserDialog);
        webView_->setObjectName("webView_");
        webView_->setProperty("url", QVariant(QUrl(QString::fromUtf8("about:blank"))));

        verticalLayout->addWidget(webView_);

        progressBar_ = new QProgressBar(BrowserDialog);
        progressBar_->setObjectName("progressBar_");
        progressBar_->setValue(24);

        verticalLayout->addWidget(progressBar_);


        retranslateUi(BrowserDialog);

        QMetaObject::connectSlotsByName(BrowserDialog);
    } // setupUi

    void retranslateUi(QDialog *BrowserDialog)
    {
        BrowserDialog->setWindowTitle(fcitx::tr2fcitx("Dialog", nullptr));
    } // retranslateUi

};

namespace Ui {
    class BrowserDialog: public Ui_BrowserDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_BROWSERDIALOG_H
